currentage: A Current Age Function

Description Usage Arguments Value Examples

View source: R/agefunctions.R

Description

This function calculates a current age in years when given a birth year.

Usage

1
currentage(birthyear = currentyear)

Arguments

birthyear

A four digit number indicating a year of birth?

Value

Current age in years

Examples

1
2
# Calculate the age of someone born in 1980
currentage(1980)

JJVandeleest/currentage documentation built on May 26, 2019, 3:31 p.m.