Description Usage Arguments Value Examples
This function calculates a current age in years when given a birth year.
1 | currentage(birthyear = currentyear)
|
birthyear |
A four digit number indicating a year of birth? |
Current age in years
1 2 | # Calculate the age of someone born in 1980
currentage(1980)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.